Learn R Programming

jaccard (version 0.1.2)

jaccard.rahman: Compute p-value using the EC-BLAST method

Description

In the EC-BLAST paper, Rahman et al. (2014) provide the following description: The mean (\(\mu\)) and s.d. (\(\sigma\)) of the similarity scores are used to define the z score, \(z = (Tw - \mu)/\sigma\). For the purpose of calculating the P value, only hits with T > 0 are considered. The P value w is derived from the z score using an extreme value distribution \(P = 1 - \exp\left(-e^{-z\pi/\sqrt{6} - \Gamma'(1)}\right)\), where the Euler-Mascheroni constant \(\Gamma'(1) \approx 0.577215665\).

Usage

jaccard.rahman(j)

Value

jaccard.rahman returns a numeric vector of p-values

Arguments

j

a numeric vector of observed Jaccard coefficients (uncentered)

References

Rahman, Cuesta, Furnham, Holliday, and Thornton (2014) EC-BLAST: a tool to automatically search and compare enzyme reactions. Nature Methods, 11(2) https://www.nature.com/articles/nmeth.2803