a method to compute a p-value ("mca", "bootstrap", "asymptotic", or "exact")
px
probability of successes in x (optional)
py
probability of successes in y (optional)
verbose
whether to print progress messages
...
optional arguments for specific computational methods
Optional arguments for <code>method="bootstrap"</code>
fix
whether to fix (i.e., not resample) x and/or y
B
a total bootstrap iteration
seed
a seed for a random number generator
Optional arguments for <code>method="mca"</code>
accuracy
an error bound on approximating a multinomial distribution
error.type
an error type on approximating a multinomial distribution ("average", "upper", "lower")
seed
a seed for the random number generator.
Details
There exist four methods to compute p-values of Jaccard/Tanimoto similarity coefficients:
mca, bootstrap, asymptotic, and exact. This is simply a wrapper function for
corresponding four functions in this package: jaccard.test.mca, jaccard.test.bootstrap, jaccard.test.asymptotic, and jaccard.test.exact.
We recommand using either mca or bootstrap methods,
since the exact solution is slow for a moderately large vector and asymptotic approximation may be inaccurate depending on the input vector size.
The bootstrap method uses resampling with replacement binary vectors to compute a p-value (see optional arguments).
The mca method uses the measure concentration algorithm that estimates the multinomial distribution with a known error bound (specified by an optional argument accuracy).